@@ -69,8 +69,11 @@ class CircleMember(Model):
 @receiver(post_save, sender=CircleMember)
 def fix_user_hubl_workaround_493(sender, instance, **kwargs):
     if not instance.user:
-        instance.user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, "")
-        instance.save()
+        try:
+            instance.user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, "")
+            instance.save()
+        except:
+            instance.delete()
 
 @receiver(pre_save, sender=Circle)
 def set_jabberid(sender, instance, **kwargs):
